using System;
using System.Collections.Generic;
using System.Text;
using System.Reflection;

namespace Jefferies.Common.Data.Collections.GridHelper
{
    public class RowItemDescriptor
    {
		private Type _type;

		public RowItemDescriptor(Type type)
		{
			_type	= type;
		}

        public string[] GetDefaultlColumnNames()
        {
			RowItemFormatAttribute[] formatAttributes = GetFormatAttributes();
            List<string> result = new List<string>();
			for (int i = 0; i < formatAttributes.Length; i++)
            {
				if (formatAttributes[i].ShowByDefault)
                {
					result.Add(formatAttributes[i].Name);
                }
            }
            return result.ToArray();
        }
        
		private PropertyInfo[] _properties;
        public PropertyInfo[] GetProperties()
        {
			if (_properties == null)
			{
				_properties = _type.GetProperties(BindingFlags.Public | BindingFlags.Instance);
			}
			return _properties;
        }

		private RowItemFormatAttribute[] _formatAttributes;
        public RowItemFormatAttribute[] GetFormatAttributes()
        {
			if (_formatAttributes == null)
			{
				List<RowItemFormatAttribute> attributeBuffer = new List<RowItemFormatAttribute>();
				foreach (PropertyInfo property in GetProperties())
				{
					object[] attributes = property.GetCustomAttributes(typeof(RowItemFormatAttribute), true);
					if (attributes.Length != 0)
					{
						RowItemFormatAttribute attr = (RowItemFormatAttribute)attributes[0];
						attributeBuffer.Add(attr);
					}
				}
				_formatAttributes	= attributeBuffer.ToArray();
			}
            return _formatAttributes;
        }

        public PropertyInfo GetPropertyInfoForAttribute(Attribute attribute)
        {
			foreach (PropertyInfo property in GetProperties())
            {
                object[] attributes = property.GetCustomAttributes(attribute.GetType(), true);
                if (Array.IndexOf(attributes, attribute) != -1)
                {
                    return property;
                }
            }
            return null;
        }

        public int[] GetDefaultWidths()
        {
			RowItemFormatAttribute[] formatAttributes = GetFormatAttributes();
            List<int> result = new List<int>();
            result.Add(0);
			for (int i = 0; i < formatAttributes.Length; i++)
            {
				result.Add(formatAttributes[i].Width);
            }
            return result.ToArray();
        }
    }
}
