using System;
using System.Reflection;
using System.Collections.Generic;
using System.Text;

namespace Jefferies.Common.Data.Collections.GridHelper
{
    public enum RowItemHAlign { Left, Centre, Right };
        
    [AttributeUsage(AttributeTargets.Property)]
    public class RowItemFormatAttribute : Attribute
    {
        private string _name;
		private bool _allowFilter;
		private bool _isCurrency;
		private string _format;
        private int _order;
        private string _aggregationFormat;
        private RowItemHAlign _hAlign;
        private int _defaultWidth = 70;
        private bool _showByDefault = true;
		private bool _readOnly	= false;

        public RowItemFormatAttribute(string name)
            : this(name, null)
        {
        }

        public RowItemFormatAttribute(string name, string format)
        {
            this._name			= name;
            this._format		= format;
			this._allowFilter	= false;
			this._isCurrency	= false;
			this._hAlign		= RowItemHAlign.Right;
        }

        public RowItemHAlign @HAlign
        {
            get { return this._hAlign; }
            set { this._hAlign = value; }
        }

		public bool ReadOnly
		{
			get
			{
				return _readOnly;
			}
			set
			{
				_readOnly	= value;
			}
		}

        public string AggregationFormat
        {
            get { return this._aggregationFormat; }
            set { this._aggregationFormat = value; }
        }

        public string Format
        {
            get { return this._format; }
            set { this._format = value; }
        }

        public bool ShowByDefault
        {
            get { return this._showByDefault; }
            set { this._showByDefault = value; }
        }

        public string Name
        {
            get { return this._name; }
        }

		public bool AllowFilter
		{
			get
			{
				return this._allowFilter;
			}
			set
			{
				this._allowFilter = value;
			}
		}

		public bool IsCurrency
		{
			get
			{
				return this._isCurrency;
			}
			set
			{
				this._isCurrency = value;
			}
		}

		public int Order
        {
            get { return this._order; }
            set { this._order = value; }
        }

        public int Width
        {
            get { return this._defaultWidth; }
            set { this._defaultWidth = value; }
        }

        public override bool Equals(object obj)
        {
            if (obj is RowItemFormatAttribute)
            {
                RowItemFormatAttribute other = (RowItemFormatAttribute)obj;
                return this._name == other._name;
            }
            else
            {
                return false;
            }
        }

        public override int GetHashCode()
        {
            return base.GetHashCode();
        }
    }
}
