using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Text;
using System.Collections;

namespace Jefferies.Common.Data.Collections.GridHelper
{
	public class RowItemList<T> : CollectionBase, IBindingList where T : RowItem, new()
    {
		private ListChangedEventArgs resetEvent = new ListChangedEventArgs(ListChangedType.Reset, -1);
		private ListChangedEventHandler onListChanged;

		public T this[int index]
		{
			get
			{

				return (T) (List[index]);
			}
			set
			{
				List[index]	= value;
			}
		}

		public int Add(T value)
		{
			return List.Add(value);
		}

		public T AddNew()
		{
			return (T) ((IBindingList) this).AddNew();
		}

		public void Remove(T value)
		{
			List.Remove(value);
		}

		protected virtual void OnListChanged(ListChangedEventArgs e)
		{
			if (onListChanged != null)
			{
				onListChanged(this, e);
			}
		}

		protected override void OnClear()
		{
			foreach (T item in List)
			{
				item.Parent = null;
			}
		}

		protected override void OnClearComplete()
		{
			OnListChanged(resetEvent);
		}

		protected override void OnInsertComplete(int index, object value)
		{
			T item = (T) value;
			item.Parent = this;
			OnListChanged(new ListChangedEventArgs(ListChangedType.ItemAdded, index));
		}

		protected override void OnRemoveComplete(int index, object value)
		{
			T item = (T) value;
			item.Parent = this;
			OnListChanged(new ListChangedEventArgs(ListChangedType.ItemDeleted, index));
		}

		protected override void OnSetComplete(int index, object oldValue, object newValue)
		{
			if (oldValue != newValue)
			{
				T oldT = (T) oldValue;
				T newT = (T) newValue;

				oldT.Parent = null;
				newT.Parent = this;

				OnListChanged(new ListChangedEventArgs(ListChangedType.ItemAdded, index));
			}
		}

		// Implements IBindingList.
		bool IBindingList.AllowEdit
		{
			get
			{
				return true;
			}
		}

		bool IBindingList.AllowNew
		{
			get
			{
				return true;
			}
		}

		bool IBindingList.AllowRemove
		{
			get
			{
				return true;
			}
		}

		bool IBindingList.SupportsChangeNotification
		{
			get
			{
				return true;
			}
		}

		bool IBindingList.SupportsSearching
		{
			get
			{
				return false;
			}
		}

		bool IBindingList.SupportsSorting
		{
			get
			{
				return false;
			}
		}

		// Events.
		public event ListChangedEventHandler ListChanged
		{
			add
			{
				onListChanged += value;
			}
			remove
			{
				onListChanged -= value;
			}
		}

		// Methods.
		object IBindingList.AddNew()
		{
			T item = new T();
			List.Add(item);
			return item;
		}

		// Unsupported properties.
		bool IBindingList.IsSorted
		{
			get
			{
				throw new NotSupportedException();
			}
		}

		ListSortDirection IBindingList.SortDirection
		{
			get
			{
				throw new NotSupportedException();
			}
		}


		PropertyDescriptor IBindingList.SortProperty
		{
			get
			{
				throw new NotSupportedException();
			}
		}

		// Unsupported Methods.
		void IBindingList.AddIndex(PropertyDescriptor property)
		{
			throw new NotSupportedException();
		}

		void IBindingList.ApplySort(PropertyDescriptor property, ListSortDirection direction)
		{
			throw new NotSupportedException();
		}

		int IBindingList.Find(PropertyDescriptor property, object key)
		{
			throw new NotSupportedException();
		}

		void IBindingList.RemoveIndex(PropertyDescriptor property)
		{
			throw new NotSupportedException();
		}

		void IBindingList.RemoveSort()
		{
			throw new NotSupportedException();
		}
    }
}
