using System;
using System.Collections.Generic;
using System.Collections;
using System.Collections.Specialized;
using System.Text;
using System.Data;

namespace Jefferies.Common.Data.Sql.DataModel
{
	public class SqlTable : NameObjectCollectionBase
	{
		private string _tableName;

		public SqlTable()
			: base()
		{
		}

		public SqlTable(string tableName)
			: this()
		{
			_tableName	= tableName;
		}

		/// <summary>
		/// Adds an entry with the specified name and type
		/// </summary>
		/// <param name="name"></param>
		/// <param name="type"></param>
		public void Add(string name, SqlDbType type)
		{
			base.BaseAdd(name, type);
		}

		/// <summary>
		/// Removes the entries with the specified name
		/// </summary>
		/// <param name="name"></param>
		public void Remove(string name)
		{
			base.BaseRemove(name);
		}

		/// <summary>
		/// Removes all entries from the collection
		/// </summary>
		public void Clear()
		{
			base.BaseClear();
		}

		/// <summary>
		/// Gets SqlDbType for specified index position
		/// </summary>
		/// <param name="index"></param>
		/// <returns></returns>
		public SqlDbType Get(int index)
		{
			return (SqlDbType) base.BaseGet(index);
		}

		/// <summary>
		/// Gets SqlDbType for specified field name
		/// </summary>
		/// <param name="index"></param>
		/// <returns></returns>
		public SqlDbType Get(string index)
		{
			return (SqlDbType) base.BaseGet(index);
		}

		/// <summary>
		/// Gets all field-names in the collection
		/// </summary>
		/// <returns></returns>
		public string[] GetFieldNames()
		{
			return base.BaseGetAllKeys();
		}

		/// <summary>
		/// Gets all SqlDbTypes in the collection
		/// </summary>
		/// <returns></returns>
		public SqlDbType[] GetAllSqlDbTypes()
		{
			//return (SqlDbType[]) base.BaseGetAllValues(typeof(SqlDbType));
			return null;
		}

		/// <summary>
		/// Gets the field-name of the entry at the specified position
		/// </summary>
		/// <param name="index"></param>
		/// <returns></returns>
		public string GetFieldName(int index)
		{
			return base.BaseGetKey(index);
		}

		/// <summary>
		/// Sets the value of the entry at the specified position
		/// </summary>
		/// <param name="index"></param>
		/// <param name="value"></param>
		public void Set(int index, SqlDbType value)
		{
			base.BaseSet(index, value);
		}

		/// <summary>
		/// Sets the value of the entry at the specified index
		/// </summary>
		/// <param name="index"></param>
		/// <param name="value"></param>
		public void Set(string index, SqlDbType value)
		{
			base.BaseSet(index, value);
		}

		public SqlDbType this[string index]
		{
			get
			{
				return this.Get(index);
			}
			set
			{
				this.Set(index, value);
			}
		}

		public SqlDbType this[int index]
		{
			get
			{
				return this.Get(index);
			}
			set
			{
				this.Set(index, value);
			}
		}

		#region properties

		public string TableName
		{
			get
			{
				return _tableName;
			}
			set
			{
				_tableName = value;
			}
		}
	
		#endregion

	}
}